summaryrefslogtreecommitdiff
path: root/libs/sigc++2/sigc++/functors/functor_trait.h
diff options
context:
space:
mode:
Diffstat (limited to 'libs/sigc++2/sigc++/functors/functor_trait.h')
-rw-r--r--libs/sigc++2/sigc++/functors/functor_trait.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libs/sigc++2/sigc++/functors/functor_trait.h b/libs/sigc++2/sigc++/functors/functor_trait.h
index 656d010414..0b7475273f 100644
--- a/libs/sigc++2/sigc++/functors/functor_trait.h
+++ b/libs/sigc++2/sigc++/functors/functor_trait.h
@@ -27,14 +27,14 @@
namespace sigc {
/** nil struct type.
* The nil struct type is used as default template argument in the
* unnumbered sigc::signal and sigc::slot templates.
*
* @ingroup signal
* @ingroup slot
*/
-struct nil;
+struct nil_;
/** @defgroup functors Functors
@@ -27,14 +27,14 @@
namespace sigc {
-/** nil struct type.
- * The nil struct type is used as default template argument in the
+/** nil_ struct type.
+ * The nil_ struct type is used as default template argument in the
* unnumbered sigc::signal and sigc::slot templates.
*